ucontext

Struct ucontext 

pub struct ucontext {
    pub uc_link: *mut ucontext,
    pub uc_stack: stack_t,
    pub uc_sigmask: sigset_t,
    pub uc_mcontext: mcontext,
    /* private fields */
}

Fields

uc_link: *mut ucontext

Pointer to the context that is resumed when this context returns.

uc_stack: stack_t

The stack used by this context.

uc_sigmask: sigset_t

The set of signals that are blocked when this context is active.

uc_mcontext: mcontext

A machine-specific representation of the saved context.