pub struct ucontext {
pub uc_link: *mut ucontext,
pub uc_stack: stack_t,
pub uc_sigmask: sigset_t,
pub uc_mcontext: mcontext,
/* private fields */
}Fields
uc_link: *mut ucontextPointer to the context that is resumed when this context returns.
uc_stack: stack_tThe stack used by this context.
uc_sigmask: sigset_tThe set of signals that are blocked when this context is active.
uc_mcontext: mcontextA machine-specific representation of the saved context.